# Release Process for QHub

## Release Checklist

To generate a checklist that will guide you through the release process, create an issue from the `Release Checklist`
issue template on GitHub. This issue is also used as a centralized place to discuss any release items as a team.

> NOTE:
> [Click here](https://github.com/Quansight/qhub/issues/new?assignees=&labels=type%3A+release+%F0%9F%8F%B7&template=release-checklist.md&title=%5BRELEASE%5D+-+%3Cversion%3E)
> to create a new release checklist issue.

### Testing Checklist

As part of major releases, more hands-on, in-depth testing is required to validate that the core features and services
are working as expected. To generate a checklist that will guide you through the testing process, create an issue from
the `Testing Checklist` issue template on GitHub.

> NOTE:
> [Click here](https://github.com/Quansight/qhub/issues/new?assignees=&labels=type%3A+release+%F0%9F%8F%B7&template=testing-checklist.md&title=Testing+checklist+for+%3Cversion%3E)
> to create a new testing checklist issue.
